==> apache-camel-quarkus-2.13.3-src.zip: camel-quarkus-2.13.3/integration-tests/soap/src/main/java/org/apache/camel/quarkus/component/soap/it/service/NoSuchCustomerException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.soap.it.service;

import javax.xml.ws.WebFault;

@WebFault(name = "NoSuchCustomer", targetNamespace = "http://service.it.soap.component.quarkus.camel.apache.org/")
public class NoSuchCustomerException extends Exception {
    public static final long serialVersionUID = 1L;

    private NoSuchCustomer faultInfo;

    public NoSuchCustomerException() {
        super();
    }

    public NoSuchCustomerException(String message) {
        super(message);
    }

    public NoSuchCustomerException(String message, java.lang.Throwable cause) {
        super(message, cause);
    }

    public NoSuchCustomerException(String message, NoSuchCustomer noSuchCustomer) {
        super(message);
        this.faultInfo = noSuchCustomer;
    }

    public NoSuchCustomerException(String message, NoSuchCustomer noSuchCustomer, java.lang.Throwable cause) {
        super(message, cause);
        this.faultInfo = noSuchCustomer;
    }

    public NoSuchCustomer getFaultInfo() {
        return this.faultInfo;
    }
}

==> apache-camel-quarkus-3.31.0-src.zip: camel-quarkus-3.31.0/integration-tests/soap/src/main/java/org/apache/camel/quarkus/component/soap/it/service/NoSuchCustomerException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.soap.it.service;

import jakarta.xml.ws.WebFault;

@WebFault(name = "NoSuchCustomer", targetNamespace = "http://service.it.soap.component.quarkus.camel.apache.org/")
public class NoSuchCustomerException extends Exception {
    public static final long serialVersionUID = 1L;

    private NoSuchCustomer faultInfo;

    public NoSuchCustomerException() {
        super();
    }

    public NoSuchCustomerException(String message) {
        super(message);
    }

    public NoSuchCustomerException(String message, java.lang.Throwable cause) {
        super(message, cause);
    }

    public NoSuchCustomerException(String message, NoSuchCustomer noSuchCustomer) {
        super(message);
        this.faultInfo = noSuchCustomer;
    }

    public NoSuchCustomerException(String message, NoSuchCustomer noSuchCustomer, java.lang.Throwable cause) {
        super(message, cause);
        this.faultInfo = noSuchCustomer;
    }

    public NoSuchCustomer getFaultInfo() {
        return this.faultInfo;
    }
}
